#include <R.h>
#include <Rinternals.h>

extern "C" {

  SEXP PGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP pocc_r, SEXP pdet_r, 
             SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP betaStarting_r, 
	     SEXP alphaStarting_r, SEXP zStarting_r, SEXP zLongIndx_r, 
	     SEXP muBeta_r, SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP SigmaAlpha_r, 
	     SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
	     SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
	     SEXP nChain_r);


  SEXP PGOccREDet(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XpRE_r, SEXP lambdaP_r, 
		  SEXP pocc_r, SEXP pdet_r, SEXP pDetRE_r,  
                  SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP nDetRE_r, SEXP nDetRELong_r, 
		  SEXP betaStarting_r, SEXP alphaStarting_r, 
	          SEXP sigmaSqPStarting_r, SEXP alphaStarStarting_r, 
	          SEXP zStarting_r, SEXP zLongIndx_r, 
		  SEXP alphaStarIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
		  SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP sigmaSqPA_r, 
	          SEXP sigmaSqPB_r, SEXP nSamples_r, SEXP nThreads_r, 
		  SEXP verbose_r, SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, 
		  SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

  SEXP PGOccREOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, 
		  SEXP lambdaPsi_r,
		  SEXP pocc_r, SEXP pdet_r, SEXP pOccRE_r, 
                  SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP nOccRE_r, 
		  SEXP nOccRELong_r,
		  SEXP betaStarting_r, SEXP alphaStarting_r, 
	          SEXP sigmaSqPsiStarting_r, 
		  SEXP betaStarStarting_r, 
	          SEXP zStarting_r, SEXP zLongIndx_r, 
		  SEXP betaStarIndx_r, SEXP muBeta_r, 
	          SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP SigmaAlpha_r, 
	          SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r,
	          SEXP nSamples_r, SEXP nThreads_r, 
		  SEXP verbose_r, SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, 
		  SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

  SEXP PGOccREBoth(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
		   SEXP lambdaPsi_r, SEXP lambdaP_r, 
		   SEXP pocc_r, SEXP pdet_r, SEXP pOccRE_r, SEXP pDetRE_r,  
                   SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP nOccRE_r, SEXP nDetRE_r, 
		   SEXP nOccRELong_r, SEXP nDetRELong_r, 
		   SEXP betaStarting_r, SEXP alphaStarting_r, 
	           SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r, 
		   SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
	           SEXP zStarting_r, SEXP zLongIndx_r, 
		   SEXP betaStarIndx_r, SEXP alphaStarIndx_r, SEXP muBeta_r, 
	           SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP SigmaAlpha_r, 
	           SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, SEXP sigmaSqPA_r, 
	           SEXP sigmaSqPB_r, SEXP nSamples_r, SEXP nThreads_r, 
		   SEXP verbose_r, SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, 
		   SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

  SEXP spPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, SEXP pocc_r, SEXP pdet_r, 
	       SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP betaStarting_r, SEXP alphaStarting_r, 
	       SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
	       SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
	       SEXP zLongIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
	       SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
	       SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
	       SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
	       SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
	       SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
	       SEXP currChain_r, SEXP nChain_r);

  SEXP spPGOccRE(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, SEXP XpRE_r, SEXP lambdaP_r, 
		 SEXP pocc_r, SEXP pdet_r, SEXP pDetRE_r,
	         SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP nDetRE_r, SEXP nDetRELong_r, 
		 SEXP betaStarting_r, SEXP alphaStarting_r, 
		 SEXP sigmaSqPStarting_r, SEXP alphaStarStarting_r, 
	         SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
	         SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
	         SEXP zLongIndx_r, SEXP alphaStarIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
	         SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
	         SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
		 SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
	         SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
	         SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
	         SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
		 SEXP currChain_r, SEXP nChain_r);

  SEXP spPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, SEXP pocc_r, SEXP pdet_r, 
	           SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP m_r, SEXP nnIndx_r, 
		   SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
		   SEXP betaStarting_r, SEXP alphaStarting_r, 
	           SEXP zStarting_r, SEXP phiStarting_r,
	           SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
	           SEXP zLongIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
	           SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
	           SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
		   SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
	           SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
	           SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
		   SEXP currChain_r, SEXP nChain_r);

  SEXP spPGOccNNGPRE(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, SEXP XpRE_r, 
		     SEXP lambdaP_r, SEXP pocc_r, SEXP pdet_r, SEXP pDetRE_r,
	             SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP nDetRE_r, SEXP nDetRELong_r, 
		     SEXP m_r, SEXP nnIndx_r, 
		     SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
		     SEXP betaStarting_r, SEXP alphaStarting_r, 
		     SEXP sigmaSqPStarting_r, SEXP alphaStarStarting_r, 
	             SEXP zStarting_r, SEXP phiStarting_r,
	             SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
	             SEXP zLongIndx_r, SEXP alphaStarIndx_r, 
		     SEXP muBeta_r, SEXP muAlpha_r, 
	             SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
	             SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
		     SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
		     SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
	             SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
	             SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
		     SEXP currChain_r, SEXP nChain_r);

  SEXP spPGOccPredict(SEXP J_r, SEXP pOcc_r, SEXP X0_r, SEXP q_r, 
		      SEXP obsD_r, SEXP obsPredD_r, SEXP betaSamples_r, 
		      SEXP thetaSamples_r, SEXP wSamples_r, 
		      SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, 
		      SEXP verbose_r, SEXP nReport_r);

  SEXP spPGOccNNGPPredict(SEXP coords_r, SEXP J_r, 
		          SEXP pOcc_r, SEXP m_r, SEXP X0_r, SEXP coords0_r, 
			  SEXP q_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
			  SEXP thetaSamples_r, SEXP wSamples_r, SEXP nSamples_r, 
			  SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
			  SEXP nReport_r);

  SEXP msPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP pocc_r, SEXP pdet_r, 
	       SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, SEXP betaStarting_r, 
	       SEXP alphaStarting_r, SEXP zStarting_r, SEXP betaCommStarting_r, 
	       SEXP alphaCommStarting_r, SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
	       SEXP zLongIndx_r, SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	       SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	       SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, 
	       SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
	       SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
	       SEXP nChain_r);

  SEXP msPGOccREBoth(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
	             SEXP lambdaPsi_r, SEXP lambdaP_r, SEXP pocc_r, SEXP pdet_r, 
	             SEXP pOccRE_r, SEXP pDetRE_r, SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, 
	             SEXP nOccRE_r, SEXP nDetRE_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
	             SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
	             SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
	             SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
	             SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r, 
		     SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
	             SEXP zLongIndx_r, SEXP betaStarIndx_r, SEXP alphaStarIndx_r, 
	             SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	             SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	             SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, 
	             SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
	             SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
	             SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
	             SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		     SEXP nChain_r);

  SEXP msPGOccREDet(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XpRE_r, 
	            SEXP lambdaP_r, SEXP pocc_r, SEXP pdet_r, 
	            SEXP pDetRE_r, SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, 
	            SEXP nDetRE_r, SEXP nDetRELong_r, 
	            SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
	            SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
	            SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
	            SEXP sigmaSqPStarting_r, SEXP alphaStarStarting_r, 
	            SEXP zLongIndx_r, SEXP alphaStarIndx_r, 
	            SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	            SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	            SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, 
	            SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
	            SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
	            SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		    SEXP nChain_r);

  SEXP msPGOccREOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, 
	            SEXP lambdaPsi_r, SEXP pocc_r, SEXP pdet_r, 
	            SEXP pOccRE_r, SEXP J_r, SEXP nObs_r, 
		    SEXP K_r, SEXP N_r, SEXP nOccRE_r, SEXP nOccRELong_r,
	            SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
	            SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
	            SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
	            SEXP sigmaSqPsiStarting_r, SEXP betaStarStarting_r, 
	            SEXP zLongIndx_r, SEXP betaStarIndx_r,
	            SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	            SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	            SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, 
	            SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
	            SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
	            SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		    SEXP nChain_r);

  SEXP spMsPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, SEXP pocc_r, SEXP pdet_r, 
	         SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, SEXP betaStarting_r, 
	         SEXP alphaStarting_r, SEXP zStarting_r, SEXP betaCommStarting_r, 
	         SEXP alphaCommStarting_r, SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
		 SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		 SEXP nuStarting_r, SEXP zLongIndx_r, SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	         SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	         SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, SEXP phiA_r, 
		 SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, 
		 SEXP nuA_r, SEXP nuB_r, SEXP tuning_r, 
		 SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, 
	         SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, SEXP nBurn_r, 
		 SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

  SEXP spMsPGOccRE(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, 
		   SEXP XpRE_r, SEXP lambdaP_r, SEXP pocc_r, SEXP pdet_r, 
	           SEXP pDetRE_r, SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, SEXP nDetRE_r, 
		   SEXP nDetRELong_r, SEXP betaStarting_r, 
	           SEXP alphaStarting_r, SEXP zStarting_r, SEXP betaCommStarting_r, 
	           SEXP alphaCommStarting_r, SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
		   SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		   SEXP nuStarting_r, SEXP sigmaSqPStarting_r, 
		   SEXP alphaStarStarting_r, SEXP zLongIndx_r, 
		   SEXP alphaStarIndx_r, SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	           SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	           SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, SEXP phiA_r, 
		   SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, 
		   SEXP nuA_r, SEXP nuB_r, 
		   SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, SEXP tuning_r, 
		   SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, 
	           SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, SEXP nBurn_r, 
		   SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);
 
  SEXP spMsPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, SEXP pocc_r, SEXP pdet_r, 
	             SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, SEXP m_r, SEXP nnIndx_r, 
		     SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r, 
		     SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
		     SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
		     SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
		     SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		     SEXP nuStarting_r, SEXP zLongIndx_r, SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	             SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	             SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, SEXP phiA_r, 
		     SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
		     SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
		     SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
		     SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		     SEXP nChain_r);

  SEXP spMsPGOccNNGPRE(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, 
		       SEXP XpRE_r, SEXP lambdaP_r, SEXP pocc_r, SEXP pdet_r, 
		       SEXP pDetRE_r, SEXP J_r, SEXP nObs_r, SEXP K_r, SEXP N_r, 
		       SEXP nDetRE_r, SEXP nDetRELong_r, SEXP m_r, SEXP nnIndx_r, 
		       SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r, 
		       SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
		       SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
		       SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
		       SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		       SEXP nuStarting_r, SEXP sigmaSqPStarting_r, SEXP alphaStarStarting_r, 
		       SEXP zLongIndx_r, SEXP alphaStarIndx_r, SEXP muBetaComm_r, SEXP muAlphaComm_r, 
	               SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
	               SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, SEXP phiA_r, 
		       SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
		       SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
		       SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
		       SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
		       SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		       SEXP nChain_r);

  SEXP spMsPGOccPredict(SEXP J_r, SEXP N_r, SEXP pOcc_r, SEXP X0_r, SEXP q_r, 
		      SEXP obsD_r, SEXP obsPredD_r, SEXP betaSamples_r, 
		      SEXP thetaSamples_r, SEXP wSamples_r, 
		      SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, 
		      SEXP verbose_r, SEXP nReport_r);

  SEXP spMsPGOccNNGPPredict(SEXP coords_r, SEXP J_r, SEXP N_r, 
		            SEXP pOcc_r, SEXP m_r, SEXP X0_r, SEXP coords0_r, 
			    SEXP q_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
			    SEXP thetaSamples_r, SEXP wSamples_r, SEXP nSamples_r, 
			    SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
			    SEXP nReport_r);

  SEXP intPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP pOcc_r, SEXP pDet_r, SEXP pDetLong_r, 
	        SEXP J_r, SEXP JLong_r, SEXP K_r, SEXP nObs_r, SEXP nObsLong_r, SEXP nData_r, 
		SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
		SEXP zLongIndx_r, SEXP dataIndx_r, SEXP alphaIndx_r, 
		SEXP muBeta_r, SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP sigmaAlpha_r, 
		SEXP nSamples_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
		SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, 
		SEXP nChain_r);

  SEXP spIntPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, 
		  SEXP pOcc_r, SEXP pDet_r, SEXP pDetLong_r, 
	          SEXP J_r, SEXP JLong_r, SEXP K_r, SEXP nObs_r, SEXP nObsLong_r, SEXP nData_r, 
		  SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
		  SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		  SEXP nuStarting_r, SEXP zLongIndx_r, SEXP dataIndx_r, SEXP alphaIndx_r, 
		  SEXP muBeta_r, SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP sigmaAlpha_r, 
		  SEXP phiA_r, SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, 
		  SEXP nuA_r, SEXP nuB_r, SEXP tuning_r, 
		  SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
		  SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
		  SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

  SEXP spIntPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, 
		      SEXP pOcc_r, SEXP pDet_r, SEXP pDetLong_r, 
	              SEXP J_r, SEXP JLong_r, SEXP K_r, SEXP nObs_r, SEXP nObsLong_r, SEXP nData_r, 
	              SEXP m_r, SEXP nnIndx_r, SEXP nnIndxLU_r, SEXP uIndx_r, 
		      SEXP uIndxLU_r, SEXP uiIndx_r,
		      SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
		      SEXP wStarting_r, SEXP phiStarting_r, SEXP sigmaSqStarting_r, 
		      SEXP nuStarting_r, SEXP zLongIndx_r, SEXP dataIndx_r, SEXP alphaIndx_r, 
		      SEXP muBeta_r, SEXP muAlpha_r, SEXP SigmaBeta_r, SEXP sigmaAlpha_r, 
		      SEXP phiA_r, SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r, 
		      SEXP nuA_r, SEXP nuB_r, SEXP tuning_r, SEXP covModel_r, 
		      SEXP nBatch_r, SEXP batchLength_r, 
		      SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
      	              SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, SEXP currChain_r, SEXP nChain_r);

}
